# nucosMQ
*nucosObs* serves as an observer-observable framework based on asyncio 

## Install
```
pip install nucosObs
```


## Documentation
[https://pythonhosted.org/nucosMQ](https://pythonhosted.org/nucosObs)


## Licence
MIT License

## Platforms
No specific platform dependency. Python 3.5 is minimum.


